rm(list=ls())
getwd()
# example of a directory
setwd("C:/Users/Pedro/Documents/Classes/Methods in Ecology/2012 fall") 
# Before running the script make sure you change the working directory to yours 

Hc_data <- read.table("Hcdata.txt", header=T)
Hc_pop  <- read.table("popmeanHc.txt", header=T)

### Analysis of complete dataset ###
Height_data_95 <-Hc_data$h95[Hc_data$SA95==1 & Hc_data$h95<90]
hist(Height_data_95,100,main="Histogram of Hypericum cumulicola height (cm)")
abline(v=Hc_pop$pop_mean, col="blue")
abline(v=mean(Height_data_95), col="red")
hist(Hc_pop$pop_sd^2)
mean(Height_data_95)
round(sqrt(var(Height_data_95))/sqrt(length(Height_data_95)),4)
summary(lm(Height_data_95~1))

###Sampling from the dataset###

size <-10
sample_height <- sample(Height_data_95,size)
n <- length(sample_height)
x <- sample_height

pop.mean.mean <- mean(Hc_pop$pop_mean)
pop.mean.var <- var(Hc_pop$pop_mean)
log.pop.var.mean <- mean(log(Hc_pop$pop_sd^2))
log.var.var <- var(log(Hc_pop$pop_sd^2))

## Call the packages  

library(R2OpenBUGS)
library(coda)

### Bayesian Analysis with Uninformed priors###
# Write model
meanmodel<-function()
{
## Priors
  mean_height ~ dnorm(0,1.0E-6)  #uninformative prior of the mean height of the plants  
  var_height ~ dlnorm(0.0,1.0E-6)  #uninformative prior of the variance of the height of the plants  
  prec <- 1/var_height

## Likelihood
for (i in 1:nobs) # for each plant
  {
  Y[i] ~ dnorm(mean_height, prec)  # height from a normal distribution
  }
}

write.model(meanmodel,"meanmodel.txt")


# Bundle data
mean.data <- list(Y=x, nobs=n)

# Inits function
inits <- function() 
   list(var_height=100,mean_height=100)

# Parameters to estimate
params <- c("mean_height","var_height")

# MCMC settings
nc = 1 
ni=100000
nb=1000
nt=100

# Start Gibbs sampler
output_model <- bugs(data = mean.data, inits = inits, parameters = params, model = "meanmodel.txt",
n.thin = nt, n.chains = nc, n.burnin = nb, n.iter = ni, codaPkg=T)

line.coda<-read.bugs(output_model)
summary(line.coda)

### Frequentist Analysis ###

Freq_results <- array(0,c(1,4))
colnames(Freq_results) <- c("mean","sd", "2.5", "97.5")
rownames(Freq_results) <- "mean_height"
Freq_results[1,1] <- sample_mean <- mean(sample_height) 
Freq_results[1,2] <-sample_std_error <- sd(sample_height)/sqrt(size)
## calculate the upper and lower limits of the 95% confidence interval
Freq_results[1,3] <- sample_mean - qt(0.975, size-1)*sample_std_error
Freq_results[1,4] <- sample_mean + qt(0.975, size-1)*sample_std_error
Freq_results

### Bayesian Analysis with Informed priors###
pop.mean <- pop.mean.mean
pop.var  <- 1/pop.mean.var

meanmodel<-function()
{
## Priors
  mean_height ~ dnorm(m,v)   #informative prior of mean
  var_height ~ dlnorm(mv,vv) #informative prior of variance
  prec <- 1/var_height

## Likelihood
for (i in 1:nobs) # for each plant
  {
  Y[i] ~ dnorm(mean_height, prec)  # height from a normal distribution
  }
}

write.model(meanmodel,"meanmodel.txt")


# Bundle data
mean.data <- list(Y=x, nobs=n, m = pop.mean, v=pop.var, mv=log.pop.var.mean, vv=log.var.var)

# Inits function
inits <- function() 
   list(var_height=100,mean_height=100)

# Parameters to estimate
params <- c("mean_height","var_height")

# MCMC settings
nc = 1 
ni=100000
nb=1000
nt=100

# Start Gibbs sampler
output_model <- bugs(data = mean.data, inits = inits, parameters = params, model = "meanmodel.txt",
n.thin = nt, n.chains = nc, n.burnin = nb, n.iter = ni, codaPkg=T)

line.coda<-read.bugs(output_model)
summary(line.coda)